==> ejc-zdsmaterialb-api-3.0.0-20241114.034118-44-sources.jar: com/ejianc/business/zdsmaterial/accept/AcceptDetailVO.java <==
package com.ejianc.business.zdsmaterial.accept;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资验收-清单
 * 
 * @author generator
 * 
 */
public class AcceptDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long acceptId; // 验收单id
    private Integer sourceType; // 数据来源：0-发货单，1-订单，2-物料档案
    private Long sourceId; // 来源业务单据id, 来源于物料档案时为空
    private Long sourceDetailId; // 来源id
    private Long materialId; // 物资id
    private String materialName; // 物资名称
    private String materialCode; // 物资编码
    private String materialTypeName; // 物资分类名称
    private Long materialTypeId; // 物资分类id
    private String materialSerialNo; // 物资流水号
    private Long contractId; // 所属合同id
    private Long contractDetailId; // 合同明细id
    private BigDecimal contractNum; // 合同量
    private BigDecimal orderNum; // 订单量
    private BigDecimal detailNum; // 本次验收数量
    private BigDecimal deliveryNum; // 发货量
    private BigDecimal resDeliveryNum; // 发货单剩余可用量
    private BigDecimal alreadyNum; // 已验收量
    private BigDecimal detailTaxPrice; // 验收单价（含税）
    private BigDecimal detailPrice; // 验收单价
    private BigDecimal detailTaxRate; // 验收税率（含税）
    private BigDecimal detailTaxMny; // 验收金额
    private BigDecimal detailMny; // 验收金额
    private BigDecimal detailTax; // 验收税额
    private String detailUnitName; // 计量单位名称
    private Long detailUnitId; // 计量单位id
    private String propertyValue; // 属性
    private String memo; // 备注
    private Integer detailNewMatFlag; // 是否有新增材料编码：0-否，1-是
    private Integer detailHasNewPropertyVal; // 是否有新增属性：0-否，1-是
    private String productCode; //产品代码
    private Long brandId; //品牌主键
    private String brandName; // 品牌名称

    private String materialTypeCode; // 物资分类编码
    private BigDecimal resOrderNum; // 订单剩余可用量

    public BigDecimal getResOrderNum() {
        return resOrderNum;
    }

    public void setResOrderNum(BigDecimal resOrderNum) {
        this.resOrderNum = resOrderNum;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }
    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public BigDecimal getResDeliveryNum() {
        return resDeliveryNum;
    }

    public void setResDeliveryNum(BigDecimal resDeliveryNum) {
        this.resDeliveryNum = resDeliveryNum;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getAcceptId() {
        return acceptId;
    }

    public void setAcceptId(Long acceptId) {
        this.acceptId = acceptId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialSerialNo() {
        return materialSerialNo;
    }

    public void setMaterialSerialNo(String materialSerialNo) {
        this.materialSerialNo = materialSerialNo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }
    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }
    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
    public BigDecimal getAlreadyNum() {
        return alreadyNum;
    }

    public void setAlreadyNum(BigDecimal alreadyNum) {
        this.alreadyNum = alreadyNum;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailTaxRate() {
        return detailTaxRate;
    }

    public void setDetailTaxRate(BigDecimal detailTaxRate) {
        this.detailTaxRate = detailTaxRate;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }
    public String getDetailUnitName() {
        return detailUnitName;
    }

    public void setDetailUnitName(String detailUnitName) {
        this.detailUnitName = detailUnitName;
    }
    public Long getDetailUnitId() {
        return detailUnitId;
    }

    public void setDetailUnitId(Long detailUnitId) {
        this.detailUnitId = detailUnitId;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getDetailNewMatFlag() {
        return detailNewMatFlag;
    }

    public void setDetailNewMatFlag(Integer detailNewMatFlag) {
        this.detailNewMatFlag = detailNewMatFlag;
    }
    public Integer getDetailHasNewPropertyVal() {
        return detailHasNewPropertyVal;
    }

    public void setDetailHasNewPropertyVal(Integer detailHasNewPropertyVal) {
        this.detailHasNewPropertyVal = detailHasNewPropertyVal;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251113.024758-90-sources.jar: com/ejianc/business/zdsmaterial/accept/AcceptDetailVO.java <==
package com.ejianc.business.zdsmaterial.accept;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 物资验收-清单
 * 
 * @author generator
 * 
 */
public class AcceptDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long acceptId; // 验收单id
    private Integer sourceType; // 数据来源：0-发货单，1-订单，2-物料档案,3-报销清单
    private Long sourceId; // 来源业务单据id, 来源于物料档案时为空
    private Long sourceDetailId; // 来源id
    private Long materialId; // 物资id
    private String materialName; // 物资名称
    private String materialCode; // 物资编码
    private String materialTypeName; // 物资分类名称
    private Long materialTypeId; // 物资分类id
    private String materialSerialNo; // 物资流水号
    private Long contractId; // 所属合同id
    private Long contractDetailId; // 合同明细id
    private BigDecimal contractNum; // 合同量
    private BigDecimal orderNum; // 订单量
    private BigDecimal detailNum; // 本次验收数量
    private BigDecimal deliveryNum; // 发货量
    private BigDecimal resDeliveryNum; // 发货单剩余可用量
    private BigDecimal alreadyNum; // 已验收量
    private BigDecimal detailTaxPrice; // 验收单价（含税）
    private BigDecimal detailPrice; // 验收单价
    private BigDecimal detailTaxRate; // 验收税率（含税）
    private BigDecimal detailTaxMny; // 验收金额
    private BigDecimal detailMny; // 验收金额
    private BigDecimal detailTax; // 验收税额
    private String detailUnitName; // 计量单位名称
    private Long detailUnitId; // 计量单位id
    private String propertyValue; // 属性
    private String memo; // 备注
    private Integer detailNewMatFlag; // 是否有新增材料编码：0-否，1-是
    private Integer detailHasNewPropertyVal; // 是否有新增属性：0-否，1-是
    private String productCode; //产品代码
    private Long brandId; //品牌主键
    private String brandName; // 品牌名称

    private String materialTypeCode; // 物资分类编码
    private BigDecimal resOrderNum; // 订单剩余可用量

    public BigDecimal getResOrderNum() {
        return resOrderNum;
    }

    public void setResOrderNum(BigDecimal resOrderNum) {
        this.resOrderNum = resOrderNum;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }
    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public BigDecimal getResDeliveryNum() {
        return resDeliveryNum;
    }

    public void setResDeliveryNum(BigDecimal resDeliveryNum) {
        this.resDeliveryNum = resDeliveryNum;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getAcceptId() {
        return acceptId;
    }

    public void setAcceptId(Long acceptId) {
        this.acceptId = acceptId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialSerialNo() {
        return materialSerialNo;
    }

    public void setMaterialSerialNo(String materialSerialNo) {
        this.materialSerialNo = materialSerialNo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getContractDetailId() {
        return contractDetailId;
    }

    public void setContractDetailId(Long contractDetailId) {
        this.contractDetailId = contractDetailId;
    }
    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }
    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }
    public BigDecimal getAlreadyNum() {
        return alreadyNum;
    }

    public void setAlreadyNum(BigDecimal alreadyNum) {
        this.alreadyNum = alreadyNum;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailTaxRate() {
        return detailTaxRate;
    }

    public void setDetailTaxRate(BigDecimal detailTaxRate) {
        this.detailTaxRate = detailTaxRate;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }
    public String getDetailUnitName() {
        return detailUnitName;
    }

    public void setDetailUnitName(String detailUnitName) {
        this.detailUnitName = detailUnitName;
    }
    public Long getDetailUnitId() {
        return detailUnitId;
    }

    public void setDetailUnitId(Long detailUnitId) {
        this.detailUnitId = detailUnitId;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getDetailNewMatFlag() {
        return detailNewMatFlag;
    }

    public void setDetailNewMatFlag(Integer detailNewMatFlag) {
        this.detailNewMatFlag = detailNewMatFlag;
    }
    public Integer getDetailHasNewPropertyVal() {
        return detailHasNewPropertyVal;
    }

    public void setDetailHasNewPropertyVal(Integer detailHasNewPropertyVal) {
        this.detailHasNewPropertyVal = detailHasNewPropertyVal;
    }
    
}
